# Changelog

## [Unreleased]

Nothing noticeable unreleased.

## v2025.3: Three in one

This release added three new commands:

- `y2 xcode build-and-upload`
- `y2 xcode bump`
- `y2 clean`

## v2025.2: A toast to Apple's Human Interface Guidelines

This release added the `y2 hig [download|extract]` commands, used for fetching data to feed the [Daily HIG bot](https://mastodon.social/@daily_hig).

## v2025.1

Initial release.
